"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.createMockProxy = (objectName = 'mock') => {
    const cache = new Map();
    const handler = {
        get: (_, name) => {
            if (name === 'mockClear') {
                return () => cache.clear();
            }
            if (!cache.has(name)) {
                cache.set(name, jest.fn().mockName(`${objectName}.${String(name)}`));
            }
            return cache.get(name);
        },
    };
    return new Proxy({}, handler);
};
exports.createProxyFromMock = (mock) => {
    if (!jest.isMockFunction(mock)) {
        throw new Error(`Expected ${mock} to be a jest mock.\n` +
            `If you want to mock a module, make sure you have called "jest.mock('<module name>')".`);
    }
    const proxy = exports.createMockProxy();
    mock.mockImplementation(() => proxy);
    return proxy;
};
//# sourceMappingURL=index.js.map